@@ -1,20 +1,23 @@
-/*=========================================================================
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
-  Program:   ORFEO Toolbox
-  Language:  C++
-  Date:      $Date$
-  Version:   $Revision$
-
-
-  Copyright (c) Centre National d'Etudes Spatiales. All rights reserved.
-  See OTBCopyright.txt for details.
-
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
 #ifndef otbOGRVersionProxy_h
 #define otbOGRVersionProxy_h
 
@@ -23,6 +26,16 @@
 #include "otbConfigure.h"
 #include "itkMacro.h"
 
+#if defined(_MSC_VER)
+#pragma warning ( push )
+#pragma warning ( disable: 4251 )
+#include "ogr_core.h" // OGR enums
+#pragma warning ( pop )
+#else
+#include "ogr_core.h" // OGR enums
+#endif
+
+
 #ifdef OTB_USE_GDAL_20
 class GDALDataset;
 class GDALDriver;
@@ -40,6 +53,12 @@ namespace ogr
 namespace version_proxy
 {
 
+/**
+* With Gdal >= 2.0, this function will test equality between type and
+* OFTInteger64 enum. Otherwise, it returns false. 
+*/
+OTBGdalAdapters_EXPORT bool IsOFTInteger64(OGRFieldType type);
+
 /** 
  * This namespace holds proxy functions hiding interface changes in gdal 2.0 
  *
