@@ -1,20 +1,23 @@
-/*=========================================================================
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
- Program:   ORFEO Toolbox
- Language:  C++
- Date:      $Date$
- Version:   $Revision$
-
-
- Copyright (c) Centre National d'Etudes Spatiales. All rights reserved.
- See OTBCopyright.txt for details.
-
-
- This software is distributed WITHOUT ANY WARRANTY; without even
- the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- PURPOSE.  See the above copyright notices for more information.
-
- =========================================================================*/
 #include "otbWrapperApplication.h"
 #include "otbWrapperApplicationFactory.h"
 #include "otbCoordinateToName.h"
@@ -57,8 +60,8 @@ private:
     SetDocAuthors("OTB-Team");
     SetDocSeeAlso(" ");
 
-    AddDocTag("Utilities");
     AddDocTag(Tags::Manip);
+    AddDocTag("Utilities");
     AddDocTag(Tags::Meta);
 
     AddParameter(ParameterType_InputImage,  "in",   "Input Image");
@@ -243,6 +246,8 @@ private:
 
     // Doc example parameter settings
     SetDocExampleParameterValue("in", "QB_Toulouse_Ortho_XS.tif");
+
+    SetOfficialDocLink();
   }
 
   void DoUpdateParameters() ITK_OVERRIDE
@@ -262,7 +267,7 @@ private:
     ImageMetadataInterfaceType::Pointer metadataInterface = ImageMetadataInterfaceFactory::CreateIMI(inImage->GetMetaDataDictionary());
 
     //Get number of bands
-    SetParameterInt("numberbands", inImage->GetNumberOfComponentsPerPixel());
+    SetParameterInt("numberbands",inImage->GetNumberOfComponentsPerPixel(), false);
     ossOutput << "\tNumber of bands : " << GetParameterInt("numberbands") << std::endl;
     std::vector<bool> noDataValueAvailable;
     bool ret = itk::ExposeMetaData<std::vector<bool> >(inImage->GetMetaDataDictionary(),MetaDataKey::NoDataValueAvailable,noDataValueAvailable);
@@ -293,26 +298,26 @@ private:
       ossOutput<<std::endl;
 
     //Get image size
-    SetParameterInt("indexx", inImage->GetLargestPossibleRegion().GetIndex()[0]);
-    SetParameterInt("indexy", inImage->GetLargestPossibleRegion().GetIndex()[1]);
+    SetParameterInt("indexx",inImage->GetLargestPossibleRegion().GetIndex()[0], false);
+    SetParameterInt("indexy",inImage->GetLargestPossibleRegion().GetIndex()[1], false);
 
         ossOutput << "\tStart index :  [" << GetParameterInt("indexx") << "," << GetParameterInt("indexy") << "]" << std::endl;
 
     //Get image size
-    SetParameterInt("sizex", inImage->GetLargestPossibleRegion().GetSize()[0]);
-    SetParameterInt("sizey", inImage->GetLargestPossibleRegion().GetSize()[1]);
+    SetParameterInt("sizex",inImage->GetLargestPossibleRegion().GetSize()[0], false);
+    SetParameterInt("sizey",inImage->GetLargestPossibleRegion().GetSize()[1], false);
 
     ossOutput << "\tSize :  [" << GetParameterInt("sizex") << "," << GetParameterInt("sizey") << "]" << std::endl;
 
     //Get image origin
-    SetParameterFloat("originx", inImage->GetOrigin()[0]);
-    SetParameterFloat("originy", inImage->GetOrigin()[1]);
+    SetParameterFloat("originx",inImage->GetOrigin()[0], false);
+    SetParameterFloat("originy",inImage->GetOrigin()[1], false);
 
     ossOutput << "\tOrigin :  [" << GetParameterFloat("originx") << "," << GetParameterFloat("originy") << "]" << std::endl;
 
     //Get image spacing
-    SetParameterFloat("spacingx", inImage->GetSpacing()[0]);
-    SetParameterFloat("spacingy", inImage->GetSpacing()[1]);
+    SetParameterFloat("spacingx",inImage->GetSpacing()[0], false);
+    SetParameterFloat("spacingy",inImage->GetSpacing()[1], false);
     ossOutput << "\tSpacing :  [" << GetParameterFloat("spacingx") << "," << GetParameterFloat("spacingy") << "]" << std::endl;
 
     //Estimate ground spacing
@@ -331,14 +336,14 @@ private:
     approxGroundSpacing = groundSpacing->EvaluateAtIndex(index);
 
     //Get image estimated ground spacing (in m)
-    SetParameterFloat("estimatedgroundspacingx", approxGroundSpacing[0]);
-    SetParameterFloat("estimatedgroundspacingy", approxGroundSpacing[1]);
+    SetParameterFloat("estimatedgroundspacingx",approxGroundSpacing[0], false);
+    SetParameterFloat("estimatedgroundspacingy",approxGroundSpacing[1], false);
 
     ossOutput << "\tEstimated ground spacing (in meters): [" << GetParameterFloat("estimatedgroundspacingx") << "," << GetParameterFloat("estimatedgroundspacingy") << "]" << std::endl;
 
     ossOutput << std::endl << "Image acquisition information:" << std::endl;
 
-    SetParameterString("sensor", metadataInterface->GetSensorID());
+    SetParameterString("sensor", metadataInterface->GetSensorID(), false);
     ossOutput << "\tSensor : ";
     if (!GetParameterString("sensor").empty())
       ossOutput <<  GetParameterString("sensor");
@@ -348,11 +353,11 @@ private:
     ossOutput << "\tImage identification number: ";
     if (metadataInterface->GetImageKeywordlist().HasKey("image_id"))
       {
-      SetParameterString("id", metadataInterface->GetImageKeywordlist().GetMetadataByKey("image_id"));
+      SetParameterString("id", metadataInterface->GetImageKeywordlist().GetMetadataByKey("image_id"), false);
       ossOutput << GetParameterString("id");
       }
     ossOutput << std::endl;
-    SetParameterString("projectionref", metadataInterface->GetProjectionRef());
+    SetParameterString("projectionref", metadataInterface->GetProjectionRef(), false);
     if (!GetParameterString("projectionref").empty())
       ossOutput << "\tImage projection : " << GetParameterString("projectionref") << std::endl;
 
@@ -376,7 +381,7 @@ private:
         osstime<<"0";
       osstime<<metadataInterface->GetMinute();
       osstime<<":00";
-      SetParameterString("time", osstime.str());
+      SetParameterString("time", osstime.str(), false);
 
       ossOutput << "\tAcquisition time : " << GetParameterString("time") << std::endl;
       }
@@ -405,29 +410,29 @@ private:
 
       if( !coord2name->GetCountryName().empty() )
         {
-        SetParameterString("country", coord2name->GetCountryName());
+        SetParameterString("country", coord2name->GetCountryName(), false);
         ossOutput << "\tCountry : " << GetParameterString("country") << std::endl;
         }
       else
-        SetParameterString("country", "Not available");
+        SetParameterString("country", "Not available", false);
 
       if( !coord2name->GetPlaceName().empty() )
         {
-        SetParameterString("town", coord2name->GetPlaceName());
+        SetParameterString("town", coord2name->GetPlaceName(), false);
         ossOutput << "\tTown : " << GetParameterString("town") << std::endl;
         }
       else
-        SetParameterString("town", "Not available");
+        SetParameterString("town", "Not available", false);
 
       // Retrieve footprint
-      SetParameterFloat("ullat", ullat);
-      SetParameterFloat("ullon", ullon);
-      SetParameterFloat("urlat", urlat);
-      SetParameterFloat("urlon", urlon);
-      SetParameterFloat("lrlat", lrlat);
-      SetParameterFloat("lrlon", lrlon);
-      SetParameterFloat("lllat", lllat);
-      SetParameterFloat("lllon", lllon);
+      SetParameterFloat("ullat",ullat, false);
+      SetParameterFloat("ullon",ullon, false);
+      SetParameterFloat("urlat",urlat, false);
+      SetParameterFloat("urlon",urlon, false);
+      SetParameterFloat("lrlat",lrlat, false);
+      SetParameterFloat("lrlon",lrlon, false);
+      SetParameterFloat("lllat",lllat, false);
+      SetParameterFloat("lllon",lllon, false);
 
       ossOutput << std::endl << "Image footprint coordinates:" << std::endl;
       ossOutput << "\tUpper left corner (latitude, longitude) = [" << GetParameterFloat("ullat") << "," << GetParameterFloat("ullon") << "]" << std::endl;
@@ -439,15 +444,15 @@ private:
       {
       }
 
-    SetParameterInt("rgb.r", metadataInterface->GetDefaultDisplay()[0]);
-    SetParameterInt("rgb.g", metadataInterface->GetDefaultDisplay()[1]);
-    SetParameterInt("rgb.b", metadataInterface->GetDefaultDisplay()[2]);
+    SetParameterInt("rgb.r",metadataInterface->GetDefaultDisplay()[0], false);
+    SetParameterInt("rgb.g",metadataInterface->GetDefaultDisplay()[1], false);
+    SetParameterInt("rgb.b",metadataInterface->GetDefaultDisplay()[2], false);
 
     ossOutput << std::endl << "Image default RGB composition:" << std::endl;
     ossOutput << "\t[R, G, B] = [" << GetParameterInt("rgb.r") << "," << GetParameterInt("rgb.g") << "," << GetParameterInt("rgb.b") << "]" << std::endl;
 
-    SetParameterInt("gcp.count", metadataInterface->GetGCPCount());
-    SetParameterString("gcp.proj", metadataInterface->GetGCPProjection());
+    SetParameterInt("gcp.count",metadataInterface->GetGCPCount(), false);
+    SetParameterString("gcp.proj", metadataInterface->GetGCPProjection(), false);
 
     ossOutput << std::endl << "Ground control points information:" << std::endl;
     ossOutput << "\tNumber of GCPs = " << GetParameterInt("gcp.count") << std::endl;
@@ -476,16 +481,16 @@ private:
       ossOutput << "\t\tGround  coordinates =" << gcp_geocoord.back() << std::endl;
       }
 
-    SetParameterStringList("gcp.ids", gcp_ids);
-    SetParameterStringList("gcp.imcoord", gcp_imcoord);
-    SetParameterStringList("gcp.geocoord", gcp_geocoord);
-    SetParameterStringList("gcp.info", gcp_infos);
+    SetParameterStringList("gcp.ids", gcp_ids, false);
+    SetParameterStringList("gcp.imcoord", gcp_imcoord, false);
+    SetParameterStringList("gcp.geocoord", gcp_geocoord, false);
+    SetParameterStringList("gcp.info", gcp_infos, false);
 
     if ( IsParameterEnabled("keywordlist") )
       {
       std::ostringstream osskeywordlist;
       osskeywordlist<<metadataInterface->GetImageKeywordlist() << std::endl;
-      SetParameterString("keyword", osskeywordlist.str());
+      SetParameterString("keyword", osskeywordlist.str(), false);
 
       ossOutput << std::endl << "Image OSSIM keywordlist (optional):" << std::endl;
       ossOutput << "\t" << GetParameterString("keyword") << std::endl;
