@@ -1,20 +1,23 @@
-/*=========================================================================
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
-  Program:   ORFEO Toolbox
-  Language:  C++
-  Date:      $Date$
-  Version:   $Revision$
-
-
-  Copyright (c) Centre National d'Etudes Spatiales. All rights reserved.
-  See OTBCopyright.txt for details.
-
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
 #include <iostream>
 #include <fstream>
 #include <vector>
@@ -1202,7 +1205,23 @@ void GDALImageIO::InternalReadImageInformation()
     if ((GDALGetRasterColorInterpretation(hBand) == GCI_PaletteIndex)
         && (hTable = GDALGetRasterColorTable(hBand)) != ITK_NULLPTR)
       {
-      m_IsIndexed = true;
+
+      // Mantis: 1049 : OTB does not handle tif with NBITS=1 properly
+      // When a palette is available and pixel type is Byte, the image is
+      // automatically read as a color image (using the palette). Perhaps this
+      // behaviour should be restricted.  Comment color table interpretation in
+      // gdalimageio
+  
+      // FIXME: Better support of color table in OTB
+      // - disable palette conversion in GDALImageIO (the comments in this part
+      // of the code are rather careful)
+      // - GDALImageIO should report the palette to ImageFileReader (as a metadata ?
+      // a kind of LUT ?).
+      // - ImageFileReader should use a kind of adapter filter to convert the mono
+      // image into color.
+      
+      // Do not set indexed image attribute to true
+      //m_IsIndexed = true;
 
       unsigned int ColorEntryCount = GDALGetColorEntryCount(hTable);
 
