@@ -1,13 +1,27 @@
-//----------------------------------------------------------------------------
-//
-// "Copyright Centre National d'Etudes Spatiales"
-//
-// License:  LGPL-2
-//
-// See LICENSE.txt file in the top level directory for more details.
-//
-//----------------------------------------------------------------------------
-// $Id$
+/*
+ * Copyright (C) 2005-2017 by Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is licensed under MIT license:
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
+ */
+
 
 #include "ossimSentinel1Model.h"
 #include "ossimTraceHelpers.h"
@@ -137,6 +151,25 @@ namespace ossimplugins
       kwl.addList(theManifestKwl, true);
       kwl.addList(theProductKwl,  true);
 
+      // Rewrite burst records since model could have been debursted
+      kwl.removeKeysThatMatch(BURST_PREFIX+"*");
+      
+      add(kwl,BURST_NUMBER_KEY.c_str(),(unsigned int)theBurstRecords.size());
+
+      unsigned int burstId(0);
+      char burstPrefix[1024];
+      
+      for(std::vector<BurstRecordType>::const_iterator burstIt = theBurstRecords.begin();
+          burstIt!=theBurstRecords.end();++burstIt)
+        {
+        s_printf(burstPrefix, "%s[%d].", BURST_PREFIX.c_str(), burstId);
+        add(kwl,burstPrefix+keyStartLine,(ossim_uint32)burstIt->startLine);
+        add(kwl,burstPrefix+keyEndLine,(ossim_uint32)burstIt->endLine);
+        add(kwl,burstPrefix+keyAzimuthStartTime,burstIt->azimuthStartTime);
+        add(kwl,burstPrefix+keyAzimuthStopTime,burstIt->azimuthStopTime);
+        ++burstId;
+        }
+      
       return ossimSarSensorModel::saveState(kwl, prefix);
    }
 
@@ -235,20 +268,6 @@ namespace ossimplugins
             return false;
          }
       }
-      else
-      {
-         /* Keep this notify as WARN. code should not reach here.
-         If manifest.safe is not found then we are not loading a valid S1 dataset.
-         If the input is tiff or annotation xml, then also there must exists a
-         manifest.safe. However, we are forced to read only annotaion xml and
-         make ossimSentinel1Model out of it for the sake of
-         "ossimSentinel1ModelTest". This is not a very good idea to allow
-         reading a fake dataset.  So user must be warned!
-         */
-         ossimNotify(ossimNotifyLevel_WARN)
-            << MODULE
-            << " manifest.safe not found. but checking if xml file is valid" << "\n";
-      }
 
       // -----[ Read product file
       ossimFilename xmlFileName = file;
@@ -259,6 +278,12 @@ namespace ossimplugins
          const ossimFilename fileNameWihtoutExtension = file.fileNoExtension();
          const ossimFilename path = file.path().path();
          xmlFileName = ossimFilename(path+"/annotation/"+fileNameWihtoutExtension+".xml");
+
+         if (!xmlFileName.exists() && safeFile.empty())
+         {
+            // this is just a plain tiff file without safe nor xml
+            return false;
+         }
       }
 
       if ( !xmlFileName.exists() || !this->readProduct(xmlFileName) )
@@ -273,11 +298,30 @@ namespace ossimplugins
          All these cases should not go slient on error message. It must be FATAL errors.
 
          */
-
-         ossimNotify(ossimNotifyLevel_FATAL)
-            << MODULE
-            << " !xmlFileName.exists() || !this->readProduct(xmlFileName) fails \n";
-         return false;
+      if(traceDebug())
+        {
+        ossimNotify(ossimNotifyLevel_DEBUG)
+          << MODULE
+          << " !xmlFileName.exists() || !this->readProduct(xmlFileName) fails \n";
+        }
+        return false;
+      }
+      else
+      {
+         if ( safeFile.empty() )
+         {
+           /* Keep this notify as WARN. code should not reach here.
+           If manifest.safe is not found then we are not loading a valid S1 dataset.
+           If the input is tiff or annotation xml, then also there must exists a
+           manifest.safe. However, we are forced to read only annotaion xml and
+           make ossimSentinel1Model out of it for the sake of
+           "ossimSentinel1ModelTest". This is not a very good idea to allow
+           reading a fake dataset.  So user must be warned!
+           */
+           ossimNotify(ossimNotifyLevel_WARN)
+              << MODULE
+              << " manifest.safe not found, but xml file is valid" << "\n";
+         }
       }
 
       if ( !this->initImageSize( theImageSize ) )
