@@ -1,20 +1,23 @@
-/*=========================================================================
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
-  Program:   ORFEO Toolbox
-  Language:  C++
-  Date:      $Date$
-  Version:   $Revision$
-
-
-  Copyright (c) Centre National d'Etudes Spatiales. All rights reserved.
-  See OTBCopyright.txt for details.
-
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
 #include "otbGlImageActor.h"
 #include "otbViewSettings.h"
 #include "otbMath.h"
@@ -470,7 +473,7 @@ void GlImageActor::Render()
       }
   
     // Reset color before rendering
-    glColor3d(1.0f,1.0f,1.0f);
+    glColor4d(1.0f,1.0f,1.0f, m_ImageSettings->GetAlpha());
   
     glBegin (GL_QUADS);
     glTexCoord2f (0.0, 1.0); glVertex2f(it->m_LL[0], it->m_LL[1]);
@@ -873,13 +876,13 @@ GlImageActor
 #else
   index[ 0 ] =
     static_cast< IndexType::IndexValueType >(
-      ( physical[ 0 ] - m_Origin[ 0 ] ) / 
+      ( physical[ 0 ] + 0.5 * m_Spacing[0] - m_Origin[ 0 ] ) / 
       m_Spacing[ 0 ]
     );
 
   index[ 1 ] =
     static_cast< IndexType::IndexValueType >(
-      ( physical[ 1 ]-  m_Origin[ 1 ] ) /
+      ( physical[ 1 ] + 0.5 * m_Spacing[1] -  m_Origin[ 1 ] ) /
       m_Spacing[ 1 ]
     );
 
@@ -1273,7 +1276,7 @@ GlImageActor
                        const Point2d & in,
                        bool isPhysical ) const
 {
-  out = ViewportToImageTransform( in, isPhysical );
+  out = ImageToViewportTransform( in, isPhysical );
 
   return true;
 }
