@@ -1,20 +1,23 @@
-/*=========================================================================
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
-  Program:   Monteverdi
-  Language:  C++
-  Date:      $Date$
-  Version:   $Revision$
-
-
-  Copyright (c) Centre National d'Etudes Spatiales. All rights reserved.
-  See OTBCopyright.txt for details.
-
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
 
 #include "mvdMainWindow.h"
 #include "ui_mvdMainWindow.h"
@@ -82,6 +85,7 @@
 #include "mvdQuicklookViewRenderer.h"
 #include "mvdShaderWidget.h"
 #include "mvdStatusBarWidget.h"
+#include "mvdProjectionBarWidget.h"
 //
 #include "mvdApplication.h"
 #include "mvdPreferencesDialog.h"
@@ -139,7 +143,10 @@ MainWindow
   m_ShaderWidget( NULL ),
   m_FilenameDragAndDropEventFilter( NULL ),
   m_KeymapDialog( NULL ),
-  m_GLSL140( -2 )
+  m_ProjectionBarWidget( NULL ),
+  m_GLSL140( -2 ),
+  m_isGLSLAvailable( false ),
+  m_ForceNoGLSL( false )
 {
   m_UI->setupUi( this );
 
@@ -171,7 +178,7 @@ MainWindow
 /*****************************************************************************/
 bool
 MainWindow
-::CheckGLCapabilities()
+::CheckGLCapabilities( bool forceNoGLSL )
 {
   assert( m_ImageView!=NULL );
   assert( m_ImageView->GetRenderer()!=NULL );
@@ -182,35 +189,105 @@ MainWindow
   //     m_ImageView->GetRenderer()==NULL )
   //   return false;
 
-  bool isGLSL = m_ImageView->GetRenderer()->CheckGLCapabilities( &m_GLSL140 );
+  m_isGLSLAvailable =
+    m_ImageView->GetRenderer()->CheckGLCapabilities( &m_GLSL140 );
 
 #if FORCE_NO_GLSL
-  m_ImageView->GetRenderer()->SetGLSLEnabled( false );
+  qWarning() << "No-GLSL is always forced in this build!";
+
+  m_ForceNoGLSL = true;
+
+#else
+  m_ForceNoGLSL = forceNoGLSL;
 
-  isGLSL = false;
 #endif // FORCE_NO_GLSL
 
-  // MANTIS-1204
-  // {
+  bool isGLSL = m_isGLSLAvailable && !m_ForceNoGLSL;
+
+  {
+    assert( m_UI!=NULL );
+    assert( m_UI->action_GLSL!=NULL );
+
+    bool isBlocked = m_UI->action_GLSL->blockSignals( true );
+
+    m_UI->action_GLSL->setEnabled( m_isGLSLAvailable );
+    m_UI->action_GLSL->setChecked( isGLSL );
+
+    m_UI->action_GLSL->blockSignals( isBlocked );
+  }
+
+  SetGLSLEnabled( isGLSL );
+
+  return ( !m_isGLSLAvailable || m_ForceNoGLSL ) || m_isGLSLAvailable;
+}
+
+/*****************************************************************************/
+void
+MainWindow
+::SetGLSLEnabled( bool enabled )
+{
   //
-  // Forward GLSL state to quicklook view.
-  assert( GetQuicklookView()!=NULL );
-  assert( GetQuicklookView()->GetRenderer()!=NULL );
+  // Image view
+  {
+    assert( m_ImageView!=NULL );
 
-  GetQuicklookView()->GetRenderer()->SetGLSLEnabled( isGLSL );
-  // }
+    AbstractImageViewRenderer * renderer = m_ImageView->GetRenderer();
 
+    assert( renderer!=NULL );
+
+    if( renderer->SetGLSLEnabled( enabled )!=enabled )
+      {
+      renderer->ClearScene( true );
+      renderer->UpdateScene();
+
+      m_ImageView->updateGL();
+      }
+  }
+
+  {
+    ImageViewWidget * quicklookView = GetQuicklookView();
+    assert( quicklookView!=NULL );
+
+    // MANTIS-1204
+    // {
+    //
+    // Forward GLSL state to quicklook view.
+    assert( GetQuicklookView()->GetRenderer()!=NULL );
+
+    AbstractImageViewRenderer * renderer = quicklookView->GetRenderer();
+
+    assert( renderer!=NULL );
+
+    if( renderer->SetGLSLEnabled( enabled )!=enabled )
+      {
+      renderer->ClearScene( true );
+      renderer->UpdateScene();
+
+      quicklookView->updateGL();
+      }
+    // }
+  }
+
+  //
+  // Shader widget
   assert( m_ShaderWidget!=NULL );
 
-  m_ShaderWidget->SetGLSLEnabled( isGLSL );
+  m_ShaderWidget->SetGLSLEnabled( enabled );
   m_ShaderWidget->SetGLSL140Enabled( m_GLSL140>=0 );
 
+  //
+  // Status bar widget.
   assert( m_StatusBarWidget!=NULL );
 
-  m_StatusBarWidget->SetGLSLEnabled( isGLSL );
+  m_StatusBarWidget->SetGLSLEnabled( enabled );
 
-
-  return true;
+  //
+  // Paint
+  // if( mustRefresh )
+  //   {
+  //   m_ImageView->updateGL();
+  //   quicklookView->updateGL();
+  //   }
 }
 
 /*****************************************************************************/
@@ -234,6 +311,8 @@ MainWindow
 
   InitializeStatusBarWidgets();
 
+  InitializeProjectionBarWidget();
+
   InitializeRenderToolBar();
   InitializeShaderToolBar();
 
@@ -337,6 +416,8 @@ MainWindow
 
   ConnectStatusBar();
 
+  ConnectProjectionBarWidget();
+
   //
   // When everything is connected, install event-filter.
   assert( m_ImageView!=NULL );
@@ -470,7 +551,16 @@ MainWindow
     quicklookView,
     SLOT( OnApplyAllRequested() )
   );
+
+  QObject::connect(
+    controller,
+    SIGNAL( ResetEffectsRequested() ),
+    // to:
+    m_ImageView,
+    SLOT( OnResetEffectsRequested() )
+  );
   }
+
 }
 
 /*****************************************************************************/
@@ -540,6 +630,33 @@ MainWindow
   );
 }
 
+/*****************************************************************************/
+void
+MainWindow
+::ConnectProjectionBarWidget()
+{
+  assert( m_ProjectionBarWidget!=NULL );
+  assert( m_ImageView!=NULL );
+
+  QObject::connect(
+    m_ImageView,
+    SIGNAL( ScaleChanged( double, double ) ),
+    // to:
+    m_ProjectionBarWidget,
+    SLOT( SetProjectionScale( double, double ) )
+  );
+
+  QObject::connect(
+    m_ProjectionBarWidget,
+    SIGNAL( ProjectionScaleChanged( double ) ),
+    // to:
+    m_ImageView->GetManipulator(),
+    SLOT( ZoomTo( double ) )
+  );
+
+
+}
+
 /*****************************************************************************/
 #if USE_PIXEL_DESCRIPTION
 
@@ -906,7 +1023,6 @@ MainWindow
 {
   m_UI->m_RenderToolBar->addSeparator();
 
-  {
   m_UI->m_RenderToolBar->addWidget(
     new QLabel( tr( "Proj" ) )
   );
@@ -918,7 +1034,7 @@ MainWindow
 
   assert( comboBox!=NULL );
 
-  comboBox->setObjectName( "referenceLayerComboBox" );
+  comboBox->setObjectName( REFERENCE_LAYER_COMBOBOX_NAME );
   comboBox->setMinimumSize(
     QSize(
 #ifdef OTB_DEBUG
@@ -931,7 +1047,7 @@ MainWindow
   );
 
   m_UI->m_RenderToolBar->addWidget( comboBox );
-  }
+  m_UI->m_RenderToolBar->addWidget( m_ProjectionBarWidget );
 }
 
 /*****************************************************************************/
@@ -952,6 +1068,15 @@ MainWindow
   }
 }
 
+/*****************************************************************************/
+void
+MainWindow
+::InitializeProjectionBarWidget()
+{
+  assert( m_ProjectionBarWidget==NULL );
+  m_ProjectionBarWidget = new ProjectionBarWidget( m_UI->m_ShaderToolBar );
+}
+
 /*****************************************************************************/
 void
 MainWindow
@@ -1021,8 +1146,8 @@ MainWindow
   quicklookView->SetPickingEnabled( false );
   quicklookView->SetPickingDefaultStatus( false );
 
-  quicklookView->setMinimumSize(  64,  64 );
-  quicklookView->setMaximumSize( 512, 512 );
+  quicklookView->setMinimumSize(  32,  32 );
+  quicklookView->setMaximumSize( 1024, 1024 );
   quicklookView->setSizePolicy( QSizePolicy::Maximum, QSizePolicy::Maximum );
 
   return quicklookView;
@@ -1636,6 +1761,16 @@ MainWindow
 
 /*****************************************************************************/
 /* SLOTS                                                                     */
+/*****************************************************************************/
+void
+MainWindow
+::on_action_GLSL_triggered( bool checked )
+{
+  // qDebug() << this << "::on_action_GLSL_triggered(" << checked << ")";
+
+  SetGLSLEnabled( m_isGLSLAvailable && !m_ForceNoGLSL && checked );
+}
+
 /*****************************************************************************/
 void
 MainWindow
@@ -1666,8 +1801,9 @@ MainWindow
 {
   //
   // Select filename.
+  QString caption(tr("Open file..."));
   ImportImages(
-    otb::GetOpenFileNames( this, tr( "Open file..." ) )
+    otb::GetOpenFileNames( this, caption )
   );
 }
 
@@ -2420,8 +2556,8 @@ MainWindow
 
     text =
       tr( "(%1 %2 ; %3 %4 ; %5)" )
-      .arg( wgs84[ 0 ]>=0.0 ? "N" : "S" ).arg( fabs( wgs84[ 1 ] ) )
-      .arg( wgs84[ 1 ]>=0.0 ? "E" : "W" ).arg( fabs( wgs84[ 0 ] ) )
+      .arg( wgs84[ 1 ]>=0.0 ? "N" : "S" ).arg( fabs( wgs84[ 1 ] ) )
+      .arg( wgs84[ 0 ]>=0.0 ? "E" : "W" ).arg( fabs( wgs84[ 0 ] ) )
       .arg( alt );
     }
 
