@@ -1,21 +1,23 @@
-/*=========================================================================
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
-  Program:   Monteverdi
-  Language:  C++
-
-
-  Copyright (c) Centre National d'Etudes Spatiales. All rights reserved.
-  See Copyright.txt for details.
-
-  Monteverdi is distributed under the CeCILL licence version 2. See
-  Licence_CeCILL_V2-en.txt or
-  http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt for more details.
-
-  This software is distributed WITHOUT ANY WARRANTY; without even
-  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-  PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
 #include "mvdI18nCoreApplication.h"
 
 
@@ -562,34 +564,33 @@ I18nCoreApplication
 
   // QTextCodec::setCodecForCStrings( QTextCodec::codecForName("System") );
 
-  qWarning()
+  qDebug()
     << "Codec for C-strings:"
     << ( QTextCodec::codecForCStrings()!=NULL
 	 ? QTextCodec::codecForCStrings()->name()
 	 : "none" );
 
-  qWarning()
+  qDebug()
     << "Codec for Locale:"
     << ( QTextCodec::codecForLocale()!=NULL
 	 ? QTextCodec::codecForLocale()->name()
 	 : "none" );
 
-  qWarning()
+  qDebug()
     << "Codec for Tr:"
     << ( QTextCodec::codecForTr()!=NULL
 	 ? QTextCodec::codecForTr()->name()
 	 : "none" );
 
-
   //
   // 1. default UI language is english (no translation).
   QLocale sys_lc( QLocale::system() );
 
   // Trace system locale.
-  qWarning()
+  qDebug()
     << "Language:" << QLocale::languageToString( sys_lc.language() );
 
-  qWarning()
+  qDebug()
     << "Country:" << QLocale::countryToString( sys_lc.country() );
 
   // Check system locale.
