@@ -1,3 +1,22 @@
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 #include "otbWrapperOutputProcessXMLParameter.h"
 
@@ -130,8 +149,19 @@ OutputProcessXMLParameter::Write(Application::Pointer app)
 
   AddChildNodeTo(n_OTB, "version", version);
 
-  TiXmlElement *n_App;
-  n_App = AddChildNodeTo(n_OTB, "application");
+  // Parse application
+  TiXmlElement *n_App = ParseApplication(app);
+  n_OTB->LinkEndChild(n_App);
+
+  // Finally, write xml contents to file
+  doc.SaveFile( m_FileName.c_str() );
+}
+
+TiXmlElement*
+OutputProcessXMLParameter::ParseApplication(Application::Pointer app)
+{
+  TiXmlElement * n_App = new TiXmlElement("application");
+
   AddChildNodeTo(n_App, "name", app->GetName());
   AddChildNodeTo(n_App, "descr", app->GetDescription());
 
@@ -315,10 +345,7 @@ OutputProcessXMLParameter::Write(Application::Pointer app)
        }
       }
     }
-
-  // Finally, write xml contents to file
-  doc.SaveFile( m_FileName.c_str() );
-
+  return n_App;
 }
 
 } //end namespace wrapper
