@@ -1,20 +1,23 @@
-/*=========================================================================
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
-  Program:   ORFEO Toolbox
-  Language:  C++
-  Date:      $Date$
-  Version:   $Revision$
-
-
-  Copyright (c) Centre National d'Etudes Spatiales. All rights reserved.
-  See OTBCopyright.txt for details.
-
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
 #include "otbWrapperChoiceParameter.h"
 #include "otbWrapperListViewParameter.h"
 #include "otbWrapperDirectoryParameter.h"
@@ -36,6 +39,7 @@
 #include "otbWrapperInputProcessXMLParameter.h"
 #include "otbWrapperParameterKey.h"
 #include "otbWrapperRAMParameter.h"
+#include "otbWrapperProxyParameter.h"
 
 #include "otb_boost_string_header.h"
 
@@ -61,7 +65,11 @@ ParameterGroup::GetParametersKeys(bool recursive)
   for (pit = m_ParameterList.begin(); pit != m_ParameterList.end(); ++pit)
     {
     Parameter* param = *pit;
-    parameters.push_back( param->GetKey() );
+    std::string currentKey(param->GetKey());
+    parameters.push_back( currentKey );
+
+    // follow proxy parameters
+    param = this->ResolveParameter(param);
 
     if (recursive && dynamic_cast<ParameterGroup*>(param))
       {
@@ -70,7 +78,7 @@ ParameterGroup::GetParametersKeys(bool recursive)
       for (std::vector<std::string>::const_iterator it = subparams.begin();
            it != subparams.end(); ++it)
         {
-        parameters.push_back( std::string(paramAsGroup->GetKey()) + "."  + *it );
+        parameters.push_back( currentKey + "."  + *it );
         }
       }
     else if (recursive && dynamic_cast<ChoiceParameter*>(param))
@@ -81,7 +89,7 @@ ParameterGroup::GetParametersKeys(bool recursive)
       for (std::vector<std::string>::const_iterator it = subparams.begin();
            it != subparams.end(); ++it)
         {
-        parameters.push_back( std::string(paramAsChoice->GetKey()) + "."  + *it );
+        parameters.push_back( currentKey + "."  + *it );
         }
       }
     }
@@ -120,11 +128,15 @@ ParameterGroup::AddChoice(std::string paramKey, std::string paramName)
       else
         {
           itkExceptionMacro(<<parentkey << " is not a choice");
+		  
         }
     }
   else
     {
-      itkExceptionMacro(<<"No choice parameter key given");
+		itkExceptionMacro(
+					 << "No choice parameter key given: paramKey = '"
+					 << paramKey
+					 << "'");
     }
 }
 
@@ -132,37 +144,27 @@ ParameterGroup::AddChoice(std::string paramKey, std::string paramName)
 void
 ParameterGroup::ClearChoices(std::string paramKey)
 {
-  ParameterKey pKey( paramKey );
-  // Split the parameter name
-  std::vector<std::string> splitKey = pKey.Split();
 
-  std::string parentkey;
-  Parameter::Pointer parentParam;
+  Parameter * param  = GetParameterByKey(paramKey);
 
-  if (splitKey.size() > 1)
+  if(!param)
     {
-    parentkey = pKey.GetRoot();
-    parentParam = GetParameterByKey(parentkey);
+    itkExceptionMacro("Parameter "<<paramKey<<" not found");
+    }
+  
+   // param must be a choice, a listBox or this is an error
+  ListViewParameter* paramAsChoice = dynamic_cast<ListViewParameter*>(param);
+
+  if (paramAsChoice)
+    {
+    paramAsChoice->ClearChoices();
     }
   else
     {
-    parentParam = GetParameterByKey(splitKey[0]);
-    }
-
-   // parentParam must be a choice, a listBox or this is an error
-  ListViewParameter* listBoxParentAsChoice = dynamic_cast<ListViewParameter*>(parentParam.GetPointer());
-
-  if (listBoxParentAsChoice)
-    {
-    listBoxParentAsChoice->ClearChoices();
-    }
-  else
-    {
-    itkExceptionMacro(<<parentkey << " is not a ListView");
+    itkExceptionMacro(<<paramKey << " is not a ListView");
     }
 }
 
-
 void ParameterGroup::AddOutXMLParameter()
 {
   Parameter::Pointer tmpParam;
@@ -207,34 +209,25 @@ void ParameterGroup::AddInXMLParameter()
 std::vector<int>
 ParameterGroup::GetSelectedItems(std::string paramKey)
 {
+  Parameter * param  = GetParameterByKey(paramKey);
+
+  if(!param)
+    {
+    itkExceptionMacro("Parameter "<<paramKey<<" not found");
+    }
+  
+   // param must be a choice, a listBox or this is an error
+  ListViewParameter* paramAsChoice = dynamic_cast<ListViewParameter*>(param);
+  
   std::vector<int> selectedItems;
-  ParameterKey pKey( paramKey );
-  // Split the parameter name
-  std::vector<std::string> splitKey = pKey.Split();
 
-  std::string parentkey;
-  Parameter::Pointer parentParam;
-
-  if (splitKey.size() > 1)
+  if (paramAsChoice)
     {
-    parentkey = pKey.GetRoot();
-    parentParam = GetParameterByKey(parentkey);
+    selectedItems = paramAsChoice->GetSelectedItems();
     }
   else
     {
-    parentParam = GetParameterByKey(splitKey[0]);
-    }
-
-   // parentParam must be a choice, a listBox or this is an error
-  ListViewParameter* listBoxParentAsChoice = dynamic_cast<ListViewParameter*>(parentParam.GetPointer());
-
-  if (listBoxParentAsChoice)
-    {
-    selectedItems = listBoxParentAsChoice->GetSelectedItems();
-    }
-  else
-    {
-    itkExceptionMacro(<<parentkey << " is not a ListView");
+    itkExceptionMacro(<<paramKey << " is not a ListView");
     }
 
   return selectedItems;
@@ -666,14 +659,79 @@ ParameterGroup::AddParameter(Parameter::Pointer p)
   m_ParameterList.push_back(p);
 }
 
-Parameter::Pointer
-ParameterGroup::GetParameterByIndex(unsigned int i)
+bool
+ParameterGroup::ReplaceParameter(std::string &key, Parameter::Pointer p)
 {
-  return m_ParameterList[i];
+  bool ret = true;
+  ParameterKey pName(key);
+  std::vector<std::string> splitName = pName.Split();
+  std::string lastkey = pName.GetLastElement();
+  std::string parentkey = pName.GetRoot();
+  ParameterGroup* parentGroup = this;
+  if( splitName.size() > 1 )
+    {
+    Parameter* parentParam = GetParameterByKey(parentkey);
+    parentGroup = dynamic_cast<ParameterGroup*>(parentParam);
+    if (parentGroup)
+      {
+      ret = parentGroup->ReplaceParameter(lastkey, p);
+      }
+    else
+      {
+      ret = false;
+      }
+    }
+  else
+    {
+    // find current parameter in the current group
+    Parameter::Pointer oldParam;
+    ParameterListType::iterator vit;
+    for (vit = m_ParameterList.begin(); vit != m_ParameterList.end(); ++vit)
+      {
+      if (lastkey.compare((*vit)->GetKey()) == 0)
+        {
+        oldParam = *vit;
+        break;
+        }
+      }
+    if (oldParam.IsNull())
+      {
+      // parameter to replace not found : return false
+      ret = false;
+      }
+    else
+      {
+      // parameter already exists : replace it
+      *vit = p;
+      p->SetKey(lastkey);
+      }
+    }
+  if (ret)
+    {
+    if( splitName.size() > 1 )
+      {
+      p->SetRoot(parentGroup);
+      parentGroup->AddChild(p);
+      }
+    }
+  // don't check type compatibility here, we may want to handle special cases
+  // at higher level
+  return ret;
 }
 
 Parameter::Pointer
-ParameterGroup::GetParameterByKey(std::string name)
+ParameterGroup::GetParameterByIndex(unsigned int i, bool follow)
+{
+  Parameter *param = m_ParameterList[i];
+  if (follow)
+    {
+    param = this->ResolveParameter(param);
+    }
+  return Parameter::Pointer(param);
+}
+
+Parameter::Pointer
+ParameterGroup::GetParameterByKey(std::string name, bool follow)
 {
   ParameterKey pName(name);
 
@@ -701,6 +759,14 @@ ParameterGroup::GetParameterByKey(std::string name)
     itkExceptionMacro(<< "Could not find parameter " << name)
     }
 
+  // follow proxy parameters (resolve intermediate group parameter because
+  // we need to get to the requested parameter)
+  if (follow || splitName.size() > 1)
+    {
+    Parameter *rawParam = this->ResolveParameter(parentParam.GetPointer());
+    parentParam = rawParam;
+    }
+
   // If the name contains a child, make a recursive call
   if (splitName.size() > 1)
     {
@@ -774,5 +840,33 @@ ParameterGroup::GetNumberOfParameters()
   return m_ParameterList.size();
 }
 
+Parameter* ParameterGroup::ResolveParameter(Parameter *param)
+{
+  Parameter* ret = param;
+  if (ret == ITK_NULLPTR)
+    {
+    itkGenericExceptionMacro("Can't resolve NULL parameter!");
+    }
+  while (dynamic_cast<ProxyParameter*>(ret))
+    {
+    ProxyParameter* castParam = dynamic_cast<ProxyParameter*>(ret);
+    ProxyParameter::ProxyTargetType target = castParam->GetTarget();
+    ParameterGroup* targetGroup = dynamic_cast<ParameterGroup*>(target.first.GetPointer());
+    if (targetGroup)
+      {
+      ret = targetGroup->GetParameterByKey(target.second);
+      }
+    else
+      {
+      itkGenericExceptionMacro("Target group of a proxy parameter is not of type ParameterGroup");
+      }
+    if (ret == param)
+      {
+      itkGenericExceptionMacro("Cycle detected with proxy parameters!");
+      }
+    }
+  return ret;
+}
+
 }
 }
