@@ -1,4 +1,25 @@
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
 #include "otbTestMain.h"
+
 void RegisterTests()
 {
   REGISTER_TEST(otbWrapperApplicationNew);
@@ -20,6 +41,7 @@ void RegisterTests()
   REGISTER_TEST(otbWrapperDocExampleStructureTest);
   REGISTER_TEST(otbWrapperParameterKey);
   REGISTER_TEST(otbWrapperParameterListNew);
+  REGISTER_TEST(otbWrapperParameterList);
   REGISTER_TEST(otbWrapperEmptyParameterNew);
   REGISTER_TEST(otbWrapperInputImageListParameterNew);
   REGISTER_TEST(otbWrapperInputImageListParameterTest1);
