@@ -1,20 +1,23 @@
-/*=========================================================================
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
- Program:   ORFEO Toolbox
- Language:  C++
- Date:      $Date$
- Version:   $Revision$
-
-
- Copyright (c) Centre National d'Etudes Spatiales. All rights reserved.
- See OTBCopyright.txt for details.
-
-
- This software is distributed WITHOUT ANY WARRANTY; without even
- the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- PURPOSE.  See the above copyright notices for more information.
-
- =========================================================================*/
 
 #include "otbWrapperCommandLineLauncher.h"
 #include "otb_tinyxml.h"
@@ -303,19 +306,13 @@ int main(int argc, char* argv[])
   LauncherType::Pointer launcher = LauncherType::New();
 
   //if (launcher->Load(exp) == true)
-    if (launcher->Load(vexp) == true)
-    {
-    if (launcher->ExecuteAndWriteOutput() == false)
-      {
-      return EXIT_FAILURE;
-      }
-    }
-  else
-    {
-    return EXIT_FAILURE;
-    }
+  bool success = launcher->Load(vexp) && launcher->ExecuteAndWriteOutput();
 
-  return EXIT_SUCCESS;
+  // shutdown MPI after application finished
+  #ifdef OTB_USE_MPI
+  otb::MPIConfig::Instance()->terminate();
+  #endif
+  return success ? EXIT_SUCCESS : EXIT_FAILURE;
 }
 
 const std::string GetChildNodeTextOf(TiXmlElement *parentElement, std::string key)
