@@ -1,20 +1,23 @@
-/*=========================================================================
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
- Program:   ORFEO Toolbox
- Language:  C++
- Date:      $Date$
- Version:   $Revision$
-
-
- Copyright (c) Centre National d'Etudes Spatiales. All rights reserved.
- See OTBCopyright.txt for details.
-
-
- This software is distributed WITHOUT ANY WARRANTY; without even
- the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- PURPOSE.  See the above copyright notices for more information.
-
- =========================================================================*/
 #include "otbWrapperCommandLineLauncher.h"
 
 // Single value parameter
@@ -64,13 +67,6 @@ CommandLineLauncher::CommandLineLauncher() :
   m_AddProcessCommand->SetCallbackFunction(this, &CommandLineLauncher::LinkWatchers);
 }
 
-CommandLineLauncher::CommandLineLauncher(const char *) /*:
-  m_Expression(exp)*/
-{
-  m_Application = ITK_NULLPTR;
-  m_Parser = CommandLineParser::New();
-}
-
 CommandLineLauncher::~CommandLineLauncher()
 {
   this->DeleteWatcherList();
@@ -384,13 +380,13 @@ CommandLineLauncher::ParamResultType CommandLineLauncher::LoadParameters()
 
     const bool paramExists(m_Parser->IsAttributExists(std::string("-").append(paramKey), m_VExpression));
 
-    // if param is a Group, dont do anything, ParamGroup dont have values
+    // if param is a Group, don't do anything, ParamGroup don't have values
     if (type != ParameterType_Group)
       {
       // Get the attribute relative to this key as vector
       values = m_Parser->GetAttribut(std::string("-").append(paramKey), m_VExpression);
 
-      // If the param does not exists in the cli, dont try to set a
+      // If the param does not exists in the cli, don't try to set a
       // value on it, an exception will be thrown later in this function
       if (paramExists)
         {
@@ -494,7 +490,17 @@ CommandLineLauncher::ParamResultType CommandLineLauncher::LoadParameters()
                   else
                     if (type == ParameterType_ListView)
                       {
-                      dynamic_cast<ListViewParameter *> (param.GetPointer())->SetSelectedNames(values);
+                      
+                      ListViewParameter * tmpLV = dynamic_cast<ListViewParameter *>(param.GetPointer());
+
+                      if(tmpLV->GetSingleSelection() && values.size() > 1)
+                        {
+                        std::cerr << "ERROR: Invalid number of value for: \"" << paramKey
+                                  << "\", invalid number of values " << values.size() << std::endl;
+                        return INVALIDNUMBEROFVALUE;
+                        }
+                      
+                      tmpLV->SetSelectedNames(values);
                       }
                     else
                       if(values.size() != 1)
@@ -551,7 +557,7 @@ CommandLineLauncher::ParamResultType CommandLineLauncher::LoadParameters()
             }
         // Update the flag UserValue
         param->SetUserValue(true);
-        // Call the DoUpdateParameter to update dependant params
+        // Call the DoUpdateParameter to update dependent params
         m_Application->UpdateParameters();
         }
       }
@@ -570,7 +576,7 @@ CommandLineLauncher::ParamResultType CommandLineLauncher::LoadParameters()
     // it must be set if :
     //  - The param is root
     //  - The param is not root and belonging to a Mandatory Group
-    //    wich is activated
+    //    which is activated
     bool mustBeSet = false;
     const bool hasValue = m_Application->HasValue(paramKey);
 
@@ -685,12 +691,14 @@ void CommandLineLauncher::DisplayHelp()
 
   std::cerr << m_Application->GetDescription() << std::endl;
   std::cerr<<std::endl;
-  std::string link = "http://www.orfeo-toolbox.org/Applications/";
-  link.append(m_Application->GetName());
-  link.append(".html");
 
-  std::cerr << "Complete documentation: " << link << std::endl;
-  std::cerr<<std::endl;
+  std::string link = m_Application->GetDocLink();
+  if (!link.empty())
+  {
+    std::cerr << "Complete documentation: " << link << std::endl;
+    std::cerr<<std::endl;
+  }
+
   std::cerr << "Parameters: " << std::endl;
 
   const std::vector<std::string> appKeyList = m_Application->GetParametersKeys(true);
@@ -750,13 +758,21 @@ std::string CommandLineLauncher::DisplayParameterHelp(const Parameter::Pointer &
     return "";
     }
 
+  bool singleSelectionForListView = false;
+
+  if(type == ParameterType_ListView)
+    {
+    ListViewParameter * tmp = static_cast<ListViewParameter *>(param.GetPointer());
+    singleSelectionForListView = tmp->GetSingleSelection();
+    }
+
   std::ostringstream oss;
 
   // When a parameter is mandatory :
   // it must be set if :
   //  - The param is root
   //  - The param is not root and belonging to a Mandatory Group
-  //    wich is activated
+  //    which is activated
   bool isMissing = false;
   if (!m_Parser->IsAttributExists(std::string("-").append(paramKey), m_VExpression))
     {
@@ -822,7 +838,7 @@ std::string CommandLineLauncher::DisplayParameterHelp(const Parameter::Pointer &
     }
   else if (type == ParameterType_InputFilename || type == ParameterType_OutputFilename ||type == ParameterType_Directory || type == ParameterType_InputImage || type == ParameterType_OutputProcessXML || type == ParameterType_InputProcessXML ||
            type == ParameterType_ComplexInputImage || type == ParameterType_InputVectorData || type == ParameterType_OutputVectorData ||
-           type == ParameterType_String || type == ParameterType_Choice )
+           type == ParameterType_String || type == ParameterType_Choice || (type == ParameterType_ListView && singleSelectionForListView))
     {
     oss << "<string>        ";
     }
@@ -830,7 +846,7 @@ std::string CommandLineLauncher::DisplayParameterHelp(const Parameter::Pointer &
     {
     oss << "<string> [pixel]";
     }
-  else if (type == ParameterType_Choice || type == ParameterType_ListView || type == ParameterType_InputImageList ||
+  else if (type == ParameterType_Choice || (type == ParameterType_ListView && !singleSelectionForListView) || type == ParameterType_InputImageList ||
            type == ParameterType_InputVectorDataList || type == ParameterType_InputFilenameList ||
            type == ParameterType_StringList )
     {
@@ -840,7 +856,7 @@ std::string CommandLineLauncher::DisplayParameterHelp(const Parameter::Pointer &
     itkExceptionMacro("Not handled parameter type.");
 
 
-  oss<< " " << param->GetName() << " ";
+  oss<< " " << m_Application->GetParameterName(paramKey) << " ";
 
   if (type == ParameterType_OutputImage)
     {
