@@ -1,20 +1,23 @@
-/*=========================================================================
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
-  Program:   ORFEO Toolbox
-  Language:  C++
-  Date:      $Date$
-  Version:   $Revision$
-
-
-  Copyright (c) Centre National d'Etudes Spatiales. All rights reserved.
-  See OTBCopyright.txt for details.
-
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
 #include "otbWrapperQtWidgetListViewParameter.h"
 
 #include "otbWrapperQtWidgetParameterLabel.h"
@@ -70,7 +73,15 @@ void QtWidgetListViewParameter::DoCreateWidget()
 {
   m_ListView = new QListWidget();
   m_ListView->setToolTip(m_ListViewParam->GetDescription());
-  m_ListView->setSelectionMode(QAbstractItemView::ExtendedSelection);
+
+  if(m_ListViewParam->GetSingleSelection())
+    {
+    m_ListView->setSelectionMode(QAbstractItemView::SingleSelection);
+    }
+  else
+    {
+    m_ListView->setSelectionMode(QAbstractItemView::ExtendedSelection);
+    }
 
   connect( m_ListView, SIGNAL(itemSelectionChanged()), this, SLOT(SelectedItems()) );
 
@@ -97,6 +108,10 @@ void QtWidgetListViewParameter::SelectedItems()
       }
     }
   m_ListViewParam->SetSelectedItems(m_SelectedItems);
+
+  // make sure parameter is enabled
+  m_ListViewParam->SetActive(true);
+  m_ListViewParam->SetUserValue(true);
 }
 
 }
