@@ -1,20 +1,23 @@
-/*=========================================================================
+/*
+ * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
+ *
+ * This file is part of Orfeo Toolbox
+ *
+ *     https://www.orfeo-toolbox.org/
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
-  Program:   ORFEO Toolbox
-  Language:  C++
-  Date:      $Date$
-  Version:   $Revision$
-
-
-  Copyright (c) Centre National d'Etudes Spatiales. All rights reserved.
-  See OTBCopyright.txt for details.
-
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
 #include "otbWrapperQtWidgetView.h"
 
 #include "otbWrapperQtWidgetParameterGroup.h"
@@ -27,6 +30,7 @@
 
 #include "itksys/SystemTools.hxx"
 
+
 namespace otb
 {
 namespace Wrapper
@@ -40,7 +44,7 @@ QtWidgetView::QtWidgetView(Application* app)
 
 QtWidgetView::~QtWidgetView()
 {
-
+  delete m_Model;
 }
 
 void QtWidgetView::CreateGui()
@@ -61,6 +65,7 @@ void QtWidgetView::CreateGui()
 
   m_Message = new QLabel("<center><font color=\"#FF0000\">Select parameters</font></center>");
   connect( m_Model, SIGNAL(SetApplicationReady(bool)), this, SLOT(UpdateMessageAfterApplicationReady(bool)) );
+  connect( m_Model, SIGNAL(SetProgressReportDone(int)), this, SLOT(UpdateMessageAfterExecution(int)) );
   mainLayout->addWidget(m_Message);
 
   QtWidgetSimpleProgressReport * progressReport =  new QtWidgetSimpleProgressReport(m_Model);
@@ -86,10 +91,22 @@ void QtWidgetView::UpdateMessageAfterExecuteClicked()
   m_Message->setText("<center><font color=\"#FF0000\">Running</font></center>");
 }
 
+void QtWidgetView::UpdateMessageAfterExecution(int status)
+{
+  if (status >= 0)
+    {
+    m_Message->setText("<center><font color=\"#00A000\">DONE</font></center>");
+    }
+  else
+    {
+    m_Message->setText("<center><font color=\"#FF0000\">FAILED !</font></center>");
+    }
+}
+
 void QtWidgetView::UpdateMessageAfterApplicationReady( bool val )
 {
   if(val == true)
-    m_Message->setText("<center><font color=\"#00FF00\">Ready to run</font></center>");
+    m_Message->setText("<center><font color=\"#00A000\">Ready to run</font></center>");
   else
     m_Message->setText("<center><font color=\"#FF0000\">Select parameters</font></center>");
 }
@@ -129,6 +146,10 @@ QWidget* QtWidgetView::CreateFooter()
   m_QuitButton->setText(QObject::tr("Quit"));
   connect( m_QuitButton, SIGNAL(clicked()), this, SLOT(CloseSlot()) );
 
+  // Add Ctrl-Q shortcut to quit
+  m_QuitShortcut = new QShortcut(QKeySequence("Ctrl+Q"), this);
+  connect( m_QuitShortcut, SIGNAL(activated()), this, SLOT(CloseSlot()) );
+
   // Put the buttons on the right
   footerLayout->addStretch();
   footerLayout->addWidget(m_ExecButton);
@@ -147,7 +168,7 @@ QWidget* QtWidgetView::CreateDoc()
   QTextDocument * doc = new QTextDocument();
 
   std::string docContain;
-  ApplicationHtmlDocGenerator::GenerateDoc( m_Application, docContain);
+  ApplicationHtmlDocGenerator::GenerateDoc( m_Application, docContain, true);
 
   doc->setHtml(docContain.c_str());
 
